@@ -124,7 +124,7 @@ def write_excel(data: List[Dict], file_name: str, title_type=0):
             worksheet = workbook.add_sheet(sheet_name, cell_overwrite_ok=True)
             # 动态写入第一行标题列，并且添加指定的字段，如果没有在报文中增加，就新增
             column_names = list(d.keys())
-            extra = ["result", "uri", "method", "message"]
+            extra = ["result", "uri", "http_method", "message"]
             for ex_ in extra:
                 if ex_ == "result":
                     if ex_ or "result$int" not in column_names:
