@@ -20,7 +20,7 @@ _base_path = Path(__file__).resolve().parent
 # TODO： 0.根据接口报文初始化生成测试数据模板
 request_mock_data = [{
     "uri": "/biz/query/tiktok",
-    "method": "get",
+    "http_method": "get",
     "result": "2",
     "message": "参数非法，符合预期",
     "app_id": "",
@@ -28,7 +28,7 @@ request_mock_data = [{
 
 },
     {"uri": "/health_check",
-     "method": "get",
+     "http_method": "get",
      "result": "success",
      "message": "连接成功，符合预期",
      }
@@ -51,7 +51,7 @@ def api_mock_client():
 @pytest.mark.parametrize("mock_data", demo_data)
 def test_api(mock_data: dict, api_mock_client):
     http_headers = {"User-Agent": "TestApp"}
-    http_method = mock_data.pop("method")
+    http_method = mock_data.pop("http_method")
     request_uri = mock_data.pop("uri")
     test_result = mock_data.pop("result")
     test_message = mock_data.pop("message")
